Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(361)

Unified Diff: src/heap/gc-tracer.h

Issue 936773002: Always shrink initial old generation size based on survival rate. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/heap/gc-tracer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/gc-tracer.h
diff --git a/src/heap/gc-tracer.h b/src/heap/gc-tracer.h
index dc8105e7d4cc019eeb747b9fb8b29cf659bad19d..ca144b24b4801a808c1cbcfb77544b582dbd0cf9 100644
--- a/src/heap/gc-tracer.h
+++ b/src/heap/gc-tracer.h
@@ -165,12 +165,12 @@ class GCTracer {
};
- class PromotionEvent {
+ class SurvivalEvent {
public:
// Default constructor leaves the event uninitialized.
- PromotionEvent() {}
+ SurvivalEvent() {}
- explicit PromotionEvent(double promotion_ratio);
+ explicit SurvivalEvent(double survival_ratio);
double promotion_ratio_;
};
@@ -284,7 +284,7 @@ class GCTracer {
typedef RingBuffer<ContextDisposalEvent, kRingBufferMaxSize>
ContextDisposalEventBuffer;
- typedef RingBuffer<PromotionEvent, kRingBufferMaxSize> PromotionEventBuffer;
+ typedef RingBuffer<SurvivalEvent, kRingBufferMaxSize> SurvivalEventBuffer;
explicit GCTracer(Heap* heap);
@@ -300,7 +300,7 @@ class GCTracer {
void AddContextDisposalTime(double time);
- void AddPromotionRatio(double promotion_ratio);
+ void AddSurvivalRatio(double survival_ratio);
// Log an incremental marking step.
void AddIncrementalMarkingStep(double duration, intptr_t bytes);
@@ -388,10 +388,10 @@ class GCTracer {
// Returns 0 if no events have been recorded.
double ContextDisposalRateInMilliseconds() const;
// Computes the average promotion ratio based on the last recorded promotion
// events.
// Returns 0 if no events have been recorded.
- double AveragePromotionRatio() const;
+ double AverageSurvivalRatio() const;
// Returns true if at least one survival event was recorded.
bool SurvivalEventsRecorded() const;
@@ -452,8 +452,8 @@ class GCTracer {
// RingBuffer for context disposal events.
ContextDisposalEventBuffer context_disposal_events_;
- // RingBuffer for promotion events.
- PromotionEventBuffer promotion_events_;
+ // RingBuffer for survival events.
+ SurvivalEventBuffer survival_events_;
// Cumulative number of incremental marking steps since creation of tracer.
int cumulative_incremental_marking_steps_;
« no previous file with comments | « no previous file | src/heap/gc-tracer.cc » ('j') | no next file with comments »
@@ -388,10 +388,10 @@ class GCTracer {
// Returns 0 if no events have been recorded.
double ContextDisposalRateInMilliseconds() const;
- // Computes the average promotion ratio based on the last recorded promotion
+ // Computes the average survival ratio based on the last recorded survival
// events.
// Returns 0 if no events have been recorded.

Powered by Google App Engine
This is Rietveld 408576698